/*
 * Summary: interface for libxmldb
 * Description: main include file for libxmldb
 *
 * Copy: See Copyright for the status of this software.
 *
 * Author: Brian Aker
 */


#ifndef __INCLUDED_XMLROW_H
#define __INCLUDED_XMLROW_H

#include <stdio.h>
#include <string.h>
#include <assert.h>

#include <libxml/tree.h>
#include <libxml/parser.h>
#include <libxml/encoding.h>
#include <libxml/xpath.h>
#include <libxml/xpathInternals.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef struct xml_row_field_st xml_row_field_st;
typedef struct xml_row_st xml_row_st;

typedef enum {
  XML_ENGINE_NOT_NULL= 0,
  XML_ENGINE_IS_NULL= 1
} xml_row_field_is_null;

typedef enum {
  XML_ROW_TYPE_STRING= 0,
  XML_ROW_TYPE_BINARY= 1,
  XML_ROW_TYPE_NUMBER= 2,
} xml_row_types;

typedef enum {
  XML_ROW_SUCCESS= 0,
  XML_ROW_FAILURE= 1
} xml_row_return;

struct xml_row_field_st {
  xml_row_field_is_null is_null;
  size_t length;
  xmlChar *str;
  xmlChar *name;
  xml_row_types type;
  xml_row_field_st *next;
};

xml_row_return xml_row_field_add(xml_row_st *ptr, char *name, char *str, size_t length, xml_row_field_is_null is_null);

struct xml_row_st {
  char allocated;
  char clone;
  unsigned int fields;
  xmlDocPtr doc;
  xmlNodePtr row;
  xmlNsPtr name_space;
  xml_row_field_st *field;
};

void xml_row_startup();
void xml_row_shutdown();

/* */
xml_row_st *xml_row_create(xml_row_st *ptr);
void xml_row_close(xml_row_st *ptr);

char *xml_row_serialize(xml_row_st *ptr, size_t *length);

xml_row_field_st * xml_row_read(xml_row_st *ptr);

xml_row_return xml_row_field_add(xml_row_st *ptr, char *name, char *str, 
                                 size_t length, 
                                 xml_row_field_is_null is_null);
xml_row_return xml_row_field_add(xml_row_st *ptr, 
				 char *name, 
				 char *str, 
                                 size_t length, 
                                 xml_row_field_is_null is_null);
xml_row_return xml_row_set(xml_row_st *ptr, char *string, size_t length);

void xml_row_reset(xml_row_st *ptr);

#ifdef __cplusplus
}
#endif

#endif /* ndef __INCLUDED_XMLROW_H */
